@@ -6,7 +6,9 @@ from typing import List, Union
 num = Union[int, float]
 num_list = List[num]
 num_num_list = Union[num, num_list]
-
+str_list = List[str]
+str_str_list = Union[str, str_list]
+x_type = Union[int, float, str]
 
 @dataclass
 class Dataset:
@@ -30,9 +32,10 @@ class LineChart:
     def __init__(
         self,
         name: str,
-        x: List[num_num_list],
+        x: List[x_type],
         y: List[num_num_list],
-        color: str = "#CCCCCC",
+        color: str_str_list = "#CCCCCC",
+        label: str_str_list = '',
         description: str = '',
         input_updates: Dict[str, Any] = {},
     ):
@@ -40,9 +43,20 @@ class LineChart:
         self.description = description
         self.input_updates = input_updates
 
-        _, label = name.split("_")
-        dataset = Dataset(label=label, data=y,backgroundColor=color, borderColor=color)
-        self.chartdata = ChartData(labels=x, datasets=[dataset])
+        if isinstance(y[0], list):
+            dataset = []
+            for idx in range(len(y)):              
+                if isinstance(label, list) and (len(label) == len(y)): this_label = label[idx]
+                else: raise ValueError('`label` passed in to the line_chart must be of same length as `y`')
+                if isinstance(color, list) and (len(color) == len(y)): this_color = color[idx]
+                else: raise ValueError('`color` passed in to the line_chart must be of same length as `y`')
+                dataset.append(Dataset(label=this_label, data=y[idx],backgroundColor=this_color, borderColor=this_color))
+            self.chartdata = ChartData(labels=x, datasets=dataset)
+        else:
+            if not bool(label):
+                _, label = name.split("_")
+            dataset = Dataset(label=label, data=y,backgroundColor=color, borderColor=color)
+            self.chartdata = ChartData(labels=x, datasets=[dataset])
 
     def get_value(self):
         return None
